@@ -11,6 +11,10 @@ my $cv = AnyEvent->condvar;
 my $server = AnyEvent::SMTP::Server->new( port => 2525 );
 
 $server->reg_cb(
+	ready => sub {
+		my $s = shift;
+		warn "Server started on $s->{host}:$s->{port} with hostname $s->{hostname}\n";
+	},
 	client => sub {
 		my ($s,$con) = @_;
 		warn "Client from $con->{host}:$con->{port} connected\n";
